@@ -5,7 +5,7 @@ use warnings;
 use utf8;
 use Regexp::Grammars;
 
-our $VERSION = '0.05';
+our $VERSION = '0.07';
 
 sub new {
 	my ($class) = @_;
@@ -1140,7 +1140,7 @@ Lang::HL
 =head1 SYNOPSIS
 
   $> hlc <directoryName>
-  $> hlg <directoryName>
+  $> hlp <directoryName>
 
 =head1 DESCRIPTION
 
@@ -1152,7 +1152,7 @@ Rajkumar Reddy
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2022 by Rajkumar Reddy
+Copyright (C) 2022 by Rajkumar Reddy. All rights reserved.
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
